#
# spec file for package dictd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dictd
Version:        1.13.3
Release:        2.1
Summary:        DICT protocol (RFC 2229) server and command-line client
License:        BSD-3-Clause AND GPL-1.0-or-later AND GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-or-later AND MIT AND SUSE-Public-Domain
Group:          Productivity/Office/Dictionary
URL:            https://github.com/cheusov/dictd
# Source0:        https://github.com/cheusov/dictd/archive/%%{version}.tar.gz#/dictd-%%{version}.tar.gz
Source0:        https://sourceforge.net/projects/dict/files/dictd/dictd-%{version}/dictd-%{version}.tar.gz
Source1:        colorit.conf
Source2:        dictd.service
Source99:       dictd-rpmlintrc
Patch0:         dictd-1.12.1-unused-return.patch
# BuildRequires:  mk-configure
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gawk
BuildRequires:  gcc
BuildRequires:  judy-devel
BuildRequires:  libdbi-devel
BuildRequires:  libmaa-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(systemd)
# libtool-ltdl-devel  byacc
%if 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
%{?systemd_ordering}
%endif

%description
This package contains two programs. dict gives access to
electronic dictionaries on the Internet. With dictd, one can
set up a custom dictionary. To look up, for example, the word "grunt",
execute `dict grunt` at a command line. See the man pages of dict and
dictd for details.

%package devel
Summary:        Development files for dictd
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
BuildArch:      noarch

%description devel
This package contains two programs. dict gives access to
electronic dictionaries on the Internet. With dictd, one can
set up a custom dictionary. To look up, for example, the word "grunt",
execute `dict grunt` at a command line. See the man pages of dict and
dictd for details.

This package contains development files for the dictd package.

%prep
%autosetup -p1

%build
export LDFLAGS="%{?__global_ldflags}" CPPFLAGS="%{optflags} -fPIC"
# export USE_PLUGIN=1
# export PREFIX="%%{_prefix}"
# export MANDIR="%%{_mandir}"
# export SYSCONFDIR="%%{_sysconfdir}"
# export CC="%%{__cc}"
# export DESTDIR="%%{buildroot}"
# export COPTS="%%{optflags} -fPIC"
# mkc_compiler_settings
# mkcmake all
export LEXLIB="-fl"
%configure --enable-dictorg --with-plugin-dbi
# --disable-plugin
%make_build

%install
%make_install
# mkcmake install
install -D -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/colorit.conf
cat <<EOF >%{buildroot}/%{_sysconfdir}/dictd.conf
global {
    #syslog
    #syslog_facility daemon
}

# Add database definitions here...

# We stop the search here
database_exit

# Add hidden database definitions here...

EOF

cat <<EOF >%{buildroot}/%{_sysconfdir}/dict.conf
# This is an example, you should define your own servers
server dict.org
EOF

install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/dictd.service

ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcdictd

# Makefile doesn't work correctly with libdir
if [ "x%{_libdir}" != "x%{_libexecdir}" ] ; then
    mkdir -p %{buildroot}%{_libdir}/
    install -p -v -m 0755 %{buildroot}%{_libexecdir}/dictdplugin* \
        %{buildroot}%{_libdir}/
    rm -rv %{buildroot}%{_libexecdir}
fi
rm -fv %{buildroot}%{_libdir}/*.{la,a}

%check
%make_build test

%pre
%service_add_pre dictd.service

%post
%service_add_post dictd.service
touch %{_localstatedir}/log/dictd
chmod 644 %{_localstatedir}/log/dictd

%preun
%service_del_preun dictd.service

%postun
%service_del_postun dictd.service

%files
%license COPYING
%doc ANNOUNCE NEWS README example*
%doc doc/dicf.ms doc/rfc.ms doc/rfc2229.txt doc/security.doc
%{_bindir}/dict*
%{_bindir}/colorit
%{_sbindir}/*dictd
%{_libdir}/dictdplugin_dbi.so*
%{_mandir}/man1/colorit*
%{_mandir}/man1/dict*
%{_mandir}/man8/dict*
%attr(0644,root,root) %{_unitdir}/dictd.service
%config(noreplace) %{_sysconfdir}/colorit.conf
%config(noreplace) %{_sysconfdir}/dictd.conf
%config(noreplace) %{_sysconfdir}/dict.conf

%files devel
%license COPYING
%doc ANNOUNCE README TODO
%{_includedir}/*

%changelog
* Wed Jan 29 2025 Matej Cepl <mcepl@cepl.eu>
- Add default /etc/dict.conf so that dict client works by default
  as it used to (rh#2342818).
* Mon Nov 18 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 1.13.3:
  - dictd: fix buffer overflow in first/last search strategies
    (bsc#1233442).
- Remove upstreamed index-buf-ovrflw.patch.
* Fri Nov 15 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 1.13.2:
  - Remove config.{sub,guess}
  - Update version to 1.13.2
  - Rename configure.in to configure.ac
  - dictP.h: remove #include <sys/time.h>
  - configure.in: fix obsolete code
  - Fix compilation issues with gcc-14
  - Update configure script and the like (autoconf-2.72)
- Remove upstreamed patches:
  - gcc-14.patch
- Add index-buf-ovrflw.patch to fix a buffer overflow in index.c
  (courtesy of the upstream author).
* Sat Nov  2 2024 mcepl@cepl.eu
- Update to version 1.13.1+git.1730572217.cccab00:
  * dictd: listen to ipv6 and ipv4 by default
  * remove use of deprecated inet_aton and inet_ntoa
  * dictd: install dictd*.conf files to ${DATADIR}/examples/dictd by default
  * Fix problems with DICT_CONFIG_PATH and other defined came from Makefile
  * dict/Makefile: do not copy man page to ${BINDIR} :-)
  * dict/Makefile: formatting
  * dict: install samples dict.conf and dict2.conf to ${EGDIR}
  * Move examples/dict1.conf to dict/
* Thu Mar  7 2024 Matej Cepl <mcepl@cepl.eu>
- Fix License: tag (thank you, Fedora
  developers, for the research,
  https://src.fedoraproject.org/rpms/dictd/pull-request/5).
- Clean up the SPEC file
* Sun Feb 20 2022 Matej Cepl <mcepl@suse.com>
- Add dictd-rpmlintrc ... potential bashismus is completely
  innocent (gh#cheusov/dictd#13).
* Sun Feb 20 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.13.1:
  - Remove the last call of gethostbyname(3)
  - Fixes by Huy-Ngo in dictfmt help message.
- Remove ProtectHome from the systemd service file, because data
  files can be stored in $HOME and indexes need to written to.
* Mon Sep 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * dictd.service
* Mon Mar 30 2020 Matej Cepl <mcepl@suse.com>
- Update to 1.13.0:
  - dictd:
  * add support for IPv6 (the default is IPv4)
  - Add global configuration option "address_family" and
    command line options --address-family
  - Options "listen_to" and --listen-to accepts host name
    in addition to IP address, "*" means "bind to all interfaces".
  - dict:
  * add support for IPv6.
  - New command line options -4 and -6.
  - dict + dict:// URL: add support for IPv6 address
    surrounded by [ and ] symbols
  - dictfmt:
  * fix overlap of source and destination buffers in memcpy(3).
    Use memmove(3) instead. This fixes failures on Linux/musl.
  * DICTFMT_SORT environment variable may be used for
    setting non-default sort(1)
  - Fix build on recent Solaris/IllumOS (missing -lnsl at link
    time)
  - Remove support for --use-dictorg and socks5. Clean-ups for build
    system.
  - Remove support for non-utf8 dictionaries.
  - tests:
  * new test for dictd as a daemon
  * always use @AWK@
  * test/dictzip_test.in: avoid printing binary \0. This fixes test on
    some systems
* Wed Feb 19 2020 Matej Cepl <mcepl@cepl.eu>
- Update to version 1.12.1+git.1579902294.78aa097:
  * Replace inet_ntoa with gethostbyname for checking -lnsl library. It seems recent IssumOS has inet_ntoa in libc.
  * test/dictzip_test.in: use @AWK@ instead of awk
  * test/dictzip_test.in: avoid printing binary \0. This fixes test on some systems
  * Fix test/dictzip_test regression test with broken busybox-1.30 AWK implementation. Use AWK set to ./configure script
  * dictfmt: fix overlap of memcpy(3) (overlap of source and destination pointers) Use memmove(3) instead of memcpy(3). This fixes test fail on Linux/musl.
  * Fix build on Solaris-10
* Wed Jun  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  make the build dep chain cheaper by using systemd-mini.
- USe systemd_ordering instead of systemd_requires: only ask for
  systemd to be early in the transaction, but don't forcibly
  require systemd to be present.
* Wed Apr 24 2019 Matej Cepl <mcepl@suse.com>
- Update to 1.12.1+git.1555438032.190d8c6:
  - Remove --enable-dictorg from dict(1)
- Stop using obs_scm, it doesn't work, use tar_scm instead.
- Use tighter globs in %%%%files to make debuginfo generator happy.
- Clean up SPEC using spec-cleaner.
* Wed Apr 24 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 1.12.1+git.1555438032.190d8c6:
  * Remove --enable-dictorg from dict(1)
  * update config.sub and config.guess
  * dictfmt: fix merge conflict
  * dictfmt: fix compilation failure on Solaris (alloca)
  * dictfmt: DICTFMT_SORT variable is used for setting sort(1)
  * Support for --use-dictorg was removed
  * Support for socks5 was removed
  * Clean-ups for autocrap build system (headers and types)
  * Use stable sort to ensure already-sorted input stays sorted.
  * Revert "Update tables for is{space,alnum}__ (report by michael72)"
* Mon Feb  4 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
- Retire old $RPM_* shell vars.
* Sat Jan 26 2019 opensuse-packaging@opensuse.org
- Update to version 1.12.1.git.1520674574.9a2f53e:
  * update config.sub and config.guess
  * dictfmt: fix merge conflict
  * dictfmt: fix compilation failure on Solaris (alloca)
  * dictfmt: DICTFMT_SORT variable is used for setting sort(1)
  * Support for --use-dictorg was removed
  * Support for socks5 was removed
  * Clean-ups for autocrap build system (headers and types)
  * Clean-ups for autocrap build system (mbstate_t, wchar_t, wint_t, socklen_t, size_t, CODESET, alloca)
  * Use stable sort to ensure already-sorted input stays sorted.
  * Revert "Update tables for is{space,alnum}__ (report by michael72)"
* Fri Oct 12 2012 mailaender@opensuse.org
- put libmma in a separate package
- update dictd to 1.12.1
  + Fix for Debian bug #677868 reported by Stepan Golosunov.
  + Fixes for mistypes found by A. Costa. Thanks!
  + Fix for sf.net bug #3390567 reported by Ivo Danihelka.
  + Fix for sf.net bug #3398178
  + Fix for option -c. Now it works correctly.
  + Fix incorrect keyword for virtual database.
  + fix in colorit: option -c now works correctly
  + Check return value of fwrite, fflush and fclose functions. This fixes sf bug #3390567
  + Fix for Debian bug #677868 reported by Stepan Golosunov.
  + dictd.8.in: fixes for mistypes found by A. Costa. Thanks!
  + INSTALL: Fix for sf.net bug #3398178
  + fix in dictd_virtual.conf: incorrect keyword for virtual database.
  + Makefile.in: Add -c to ${INSTALL} envocations
  + Makefile.in: fix for installing from obj directory
* Wed Feb 15 2012 lars@linux-schulserver.de
- update dictd to 1.12.0:
  + New script dict_lookup for translating words and phrases
  + dictfmt: Internal buffer size was increased from 10240 to
    102400 bytes
  + dictfmt: superfluous spaces are removed not only from the beginng
    and the end of a headword but also inside a multiword headwords.
  + dictfmt spawns sort command to sort the index. When there are
    several entries for the same headword, they get sorted BY OFFSET
    AND SIZE (in addition to headwords). As a result, the order of
    identical headwords is messed up.  To fix these problem -k1,3
    option is replaced with -k1,1.
  + FIX: When search is handled by dict_search_bmh() function, the
    first character from the first entry in the index file is
    missing. Usually this is some of 00-database-* entries.
  + Other minor fixes and cleanups
- update libmaa to 1.3.1:
  + Build failure with gcc-4.6 was fixed
  + Only maa's symbols are exported from libmaa shared library
    ^^ INCLUDES ABI INCOMPATIBILITIES
  + For better conformance with POSIX/SUS xmalloc, xrealloc and
    xcalloc functions take 'size_t' args, not 'unsigned int'.
- small init script beaufify
- split out devel package
* Mon Mar  2 2009 prusnak@suse.cz
- updated to 1.11.1
  * fixed installing plugins
  * DICTFMT sorts entries in 00-database-alphabet entry
    lexicographically, that is now this order doesn't depend on
    sizeof(long)
  * DICTFMT: 'dictfmt -I' never worked
* Fri Feb  6 2009 prusnak@suse.cz
- file /var/log/dictd is now pre-created [bnc#461234]
* Tue Nov  4 2008 prusnak@suse.cz
- add missing colorit.conf [bnc#441256]
* Thu Aug 14 2008 prusnak@suse.cz
- small cleanup of spec file
- fixed preun/postun scripts
* Mon Apr  7 2008 zpetrova@suse.cz
- update to version 1.10.11
  - fixed many compiler warnings/failures.
  - dictd: while processing MATCH command unicity of only first
    column of .index was checked, but not fourth column-> fixed.
  - timestamp log marker (log_option "timestamp") is changed
    from :T: to :t:
  - dictfmt: maximum length of headwords was limited to hardcoded
    constant. Now arrays are reallocated.
  - dict: new -F|--flush option for flushing stdout after each
    definition/match
  - colorit: bashism fixed: 'echo -en' -> more portable 'printf'.
* Sun Feb 17 2008 zpetrova@suse.cz
- update to version 1.10.10:
  - dictd: added support for utf-8 symbols other than BMP
  - dict, dictl, colorit do not support paging to a special program,
    i.e.  --pager|-P option. As of this version everything is output
    to stdout only. '-P -' option is allowed.
- fixed compiler warning (bug #361613)
* Thu Jul 12 2007 zpetrova@suse.cz
- update to version 1.10.9:
- added new keywords limit_{time,matches,definitions,queries} to
  dictd to prevent DOS attacks.
- support for the case-sensitive search.
- Two new search strategies, 'first' and 'last'.
- dict -f now enables formatted output for further processing
  by other utilities.
- clean up configure.in and Makefile.in
* Thu Mar 29 2007 dmueller@suse.de
- update BuildRequires
* Fri Jul  7 2006 zpetrova@suse.cz
- update to version 1.10.6
* Wed Jun 28 2006 zpetrova@suse.cz
- update to version 1.10.5
- added configure --enable_dictorg (#169995)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 zpetrova@suse.cz
- fixed build.
* Mon Jan 16 2006 zpetrova@suse.cz
- update to version 1.10.4
* Thu Apr 21 2005 zpetrova@suse.cz
- dictd-gcc4.patch: make dictd compilable with gcc-4.0
* Sun Apr 25 2004 ro@suse.de
- added missing return value (unreached code)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu May 22 2003 coolo@suse.de
- use BuildRoot
* Wed Nov 13 2002 ro@suse.de
- fix for current bison (end all rules with ";")
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Aug 19 2002 mmj@suse.de
- Correct PreReq
* Thu Apr 25 2002 uwedr@suse.de
- Removed dictd.conf from specfile. It was not used and examples are
  in /usr/share/doc/packages/dictd anyway.
* Tue Apr 23 2002 schwab@suse.de
- Fix for 64 bit platforms.
- Use RPM_OPT_FLAGS.
* Mon Jan 14 2002 ro@suse.de
- removed START_DICTD
* Wed Dec 12 2001 uwedr@suse.de
- Added some hints in dictd.conf how to install local dictionaris
- Logging to /var/log/dictd  (see startup in /etc/init.d/dictd)
* Wed Jun  6 2001 ro@suse.de
- mark used files as Source
* Wed May 30 2001 uwedr@suse.de
- improved spec file (#7139):
  no more --with-qt and some paths corrected
- new rc.config variable START_DICTD and init script added, so the
  server dictd can be started now (if /etc/dictd.conf is configured
  properly and at least one dictionary is installed)
* Sat Dec  9 2000 nashif@suse.de
- sorted
* Tue Feb 15 2000 ro@suse.de
- man to /usr/share using macro
* Tue Feb 15 2000 aj@suse.de
- Removed prototypes for SunOS/Solaris.
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Apr 27 1999 ro@suse.de
- fixed: dict.c: stdout is not constant
* Fri Apr  9 1999 kettner@suse.de
- Created spec file from dictd-1.4.9.tar.gz using autospec script
